#
# spec file for package watchexec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           watchexec
Version:        2.2.0
Release:        bp160.1.4
Summary:        Watches a path and runs a command whenever it detects modifications.
License:        Apache-2.0
Group:          Productivity/Other
URL:            https://github.com/watchexec/watchexec
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging

%description
A simple, standalone tool that watches a path and runs a command
whenever it detects modifications.

%prep
%autosetup -a1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
# binary
install -Ddm 0755 %{buildroot}%{_bindir}
strip %{_builddir}/%{name}-%{version}/target/release/watchexec
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/watchexec %{buildroot}%{_bindir}/watchexec

# manpages
install -Dd %{buildroot}/%{_mandir}/man1
install -m 0644 doc/watchexec.1 %{buildroot}%{_mandir}/man1/watchexec.1

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%doc doc/watchexec.1.md
%{_mandir}/man1/watchexec.1%{?ext_man}
%{_bindir}/watchexec

%changelog
* Thu Oct 31 2024 Angel Yankov <angel.yankov@suse.com>
- Update to version 2.2.0:
  * Explicitly watching files that are in your .gitignore no longer requires --no-vcs-ignore (#674, #859, contributed by @TheBlek)
  * Fix Windows usage for legacy programs due to usage of UNC paths (#830, #858, contributed by @TheBlek)
  * Various dependency upgrades
- Version 2.1.0 changes:
  * New: -W, --watch-non-recursive for watching paths without also watching subfolders.
  * New: out-of-tree git repositories are now detected (i.e. when .git is a file rather than a folder)
  * Logs are also improved slightly with less nonsense at startup.
- Version 2.0.0 changelog:
  * New: --wrap-process=MODE lets you choose between using process groups, process sessions, or nothing at all. (#794)
  * New: the WATCHEXEC_TMPDIR environment variable can be used to customize where Watchexec will write temporary files, if for some reason your $TMPDIR is unwritable. (#814)
  * Fix: watchexec no longer creates a temporary file at startup. (#814)
  * Fix: the screen is no longer cleared on all events, only when starting a new process. (#809)
  * Experimental new feature - filterp rograms with -j
  * Full changelog for breaking changes in 2.0.0: https://github.com/watchexec/watchexec/releases/tag/v2.0.0
* Mon Oct 23 2023 David Anes <david.anes@suse.com>
- Remove unneeded obscpio and obsinfo files.
* Tue Oct 17 2023 david.anes@suse.com
- Update to version 1.23.0:
  * release: watchexec-cli v1.23.0 (#647)
  * Add --no-discover-ignore (#645)
  * Re-add `-d` short flag (#635)
  * Skip search for ignores when not needed (#644)
  * Clippy and update lockfile (#646)
  * release: bosion v1.0.1 (#623)
  * Update gix-config requirement from 0.24.0 to 0.25.1 in /crates/ignore-files (#622)
  * Update gix requirement from 0.47 to 0.48 in /crates/bosion (#621)
  * Fix some typos (#617)
  * Update gix-config requirement from 0.22.0 to 0.24.0 in /crates/ignore-files (#614)
* Tue May 23 2023 david.anes@suse.com
- Security fix: CVE-2023-26964, bsc#1210368
  * Latest vendored dependency h2 is 0.3.19
- Update to version 1.22.3:
  * release: watchexec-cli v1.22.3 (#590)
  * release: watchexec-filterer-ignore v1.2.1 (#589)
  * release: ignore-files v1.3.0 (#588)
  * Fix warnings (#586)
  * Add recent PRs to changelogs (#587)
  * Try to fix windows tests (#585)
  * Update completions/manpage (#584)
  * Update deps (#583)
  * Fix adding globs to the IgnoreFilter (#581)
  * fix bosion tests (#582)
* Tue May 16 2023 david.anes@suse.com
- Update to version 1.22.2:
  * release: watchexec-cli v1.22.2 (#560)
  * Normalise paths to unix on windows for filtering only (#558)
  * Disable signals on windows (#559)
  * Build manpage just before packaging (#557)
  * Fix tests-pass job (#556)
  * Update manpage (#555)
  * Fix dist-manifest gen (#554)
  * Switch away from set-output (#553)
  * release: watchexec-cli v1.22.1 (#551)
  * release: watchexec v2.3.0 (#550)
* Wed Mar 22 2023 david.anes@suse.com
- Update to version 1.22.1:
  * Fix --restart and --stop-timeout (#544, #548)
  * Fix process group not always being killed on restart (#274, #549)
* Mon Mar 20 2023 david.anes@suse.com
- Update to version 1.22.0:
  * release: watchexec-cli v1.22.0 (#538)
  * release: watchexec-filterer-globset v1.2.0 (#537)
  * release: watchexec-filterer-ignore v1.2.0 (#536)
  * release: watchexec v2.2.0 (#535)
  * release: ignore-files v1.2.0 (#534)
  * release: watchexec-events v1.0.0 (#533)
  * release: watchexec-signals v1.0.0 (#532)
  * Set new crates to zero for release (#531)
  * Fix and adjust docs (#530)
  * Rename --manpage to --manual (#529)
* Thu Feb 16 2023 david.anes@suse.com
- Update to version 1.21.1:
  * release: watchexec-cli v1.21.1 (#499)
  * release: watchexec v2.1.1 (#498)
  * Exit explicitly when we're PID 1 (#497)
  * Reset process sigmask for Rust 1.66 (#494)
  * Bump tokio from 1.23.1 to 1.24.2 (#491)
  * Avoid looping in demo (#486)
  * Add #449 to lib changelog (#481)
  * Lock CI for msrv checks (#482)
  * Update git-config requirement from 0.14.0 to 0.15.0 in /crates/ignore-files (#480)
* Thu Jan 12 2023 david.anes@suse.com
- Update to version 1.21.0:
  * release: watchexec-cli v1.21.0 (#478)
  * release: watchexec-filterer-tagged v0.2.0 (#477)
  * release: watchexec-filterer-globset v1.1.0 (#476)
  * Update PR advice for auto-merge; add meta comment (#475)
  * release: watchexec-filterer-ignore v1.1.0 (#474)
  * release: watchexec v2.1.0 (#472)
  * Add PR trigger on auto-merge enable (#473)
  * release: ignore-files v1.1.0 (#471)
  * release: project-origins v1.2.0 (#470)
  * Remove remnants of the old release flow that now break things (#469)
  * Add guide for crate release order (#468)
  * Bump tokio from 1.21.0 to 1.23.1 (#467)
  * Add usecase to README (#460)
  * Update command-group requirement from 1.0.8 to 2.0.1 in /crates/lib (#462)
  * Update git-config requirement from 0.12.0 to 0.14.0 in /crates/ignore-files (#464)
  * Update clearscreen requirement from 1.0.9 to 2.0.0 in /crates/lib (#463)
  * Bump taiki-e/install-action from 1 to 2 (#461)
  * Add to changelogs for libs (#466)
  * Add complex converter tool wrapper example to docs (#458)
  * Clippy fixes (#465)
  * Add openSUSE and MINGW packages (#453)
  * Update contrib guide (#452)
  * Add apt.cli.rs to install methods (#451)
  * Add option to exit when stdin ends (#449)
  * Update git-config requirement from 0.7.1 to 0.12.0 in /crates/ignore-files (#448)
  * Bump axum-core from 0.2.7 to 0.2.9 (#439)
  * Bump mathieudutour/github-tag-action from 6.0 to 6.1 (#435)
  * Bump softprops/action-gh-release from cd28b0f5ee8571b76cfdaa62a30d51d752317477 to 1 (#447)
  * Bump cargo-bins/release-pr from 1 to 2 (#441)
  * Bump softprops/action-gh-release from 50195ba7f6f93d1ac97ba8332a178e008ad176aa to cd28b0f5ee8571b76cfdaa62a30d51d752317477 (#438)
  * Readme: fix CI badge URL (#419)
  * Fix zsh autocomplete after using --shell=bash (#417)
  * Update release versioning
  * Learn some build optimisations from binstall (#416)
* Thu Jan 12 2023 david.anes@suse.com
- Update to version 1.20.6:
  * release: watchexec-cli v1.20.6 (#415)
  * release: watchexec v2.0.2 (#414)
  * Default release pr version to patch
  * Enable OIDC
  * Checkout before setting up signing
  * Debug gitsign
  * Document the absolute crate release order (#413)
  * Use gitsign for release-pr commits (#412)
  * release: watchexec-filterer-globset v1.0.1 (#410)
  * release: watchexec-filterer-tagged v0.1.1 (#411)
* Fri Nov  4 2022 David Anes <david.anes@suse.com>
- Remove restriction to build only on Rust tier 1 archs.
* Mon Oct 31 2022 david.anes@suse.com
- Update to version 1.20.6:
  * release: watchexec-cli v1.20.6
  * release: watchexec v2.0.2
  * Default release pr version to patch
  * Enable OIDC
  * Checkout before setting up signing
  * Debug gitsign
  * Document the absolute crate release order
  * Use gitsign for release-pr commits
  * release: watchexec-filterer-globset v1.0.1
  * release: watchexec-filterer-tagged v0.1.1
- Many changes since 1.12 version, see
  https://github.com/watchexec/watchexec for full details.
* Fri Apr 24 2020 R. Tyler Croy <rtyler@brokenco.de>
- initial packaging of watchexec
